@@ -1,4 +1,4 @@
-from pymeshfix.meshfix import *
 from pymeshfix import _meshfix
+from pymeshfix._meshfix import PyTMesh, clean_from_arrays, clean_from_file
 from pymeshfix._version import __version__
-from pymeshfix._meshfix import clean_from_arrays, clean_from_file, PyTMesh
+from pymeshfix.meshfix import *
